summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJulian de Bhal <julian.debhal@nokia.com>2012-03-29 16:22:57 +1000
committerQt by Nokia <qt-info@nokia.com>2012-04-03 03:59:59 +0200
commit9c6fac3c84b338e5c9ce0d5e923968653f152cb8 (patch)
treee4463b8b9fe7d660ca90793d4264ba0db44065eb
parent0d6a7afa1505b93d484750d87b8f899440cb26c8 (diff)
Doc and build fixes related to the QtQuick3D to Qt3D rename
Change-Id: Icf0be1fb78bcd0a546ee2909423183f5a17ef7e2 Reviewed-by: Sarah Jane Smith <sarah.j.smith@nokia.com>
-rw-r--r--README26
-rw-r--r--devices/symbian/examples/generate_examples_pkg.pl6
-rw-r--r--doc/config/qt-html-templates-online.qdocconf4
-rw-r--r--doc/config/qt-html-templates.qdocconf2
-rw-r--r--doc/config/qt3d-project.qdocconf4
-rw-r--r--doc/src/acceptance/qt3d-acceptance.qdoc15
-rw-r--r--doc/src/examples/basket.qdoc4
-rw-r--r--doc/src/examples/teapot-qml.qdoc4
-rw-r--r--doc/src/examples/teapot.qdoc2
-rw-r--r--doc/src/images/qt3d-logo.pngbin41332 -> 0 bytes
-rw-r--r--doc/src/index.qdoc63
-rw-r--r--doc/src/qt3d-building.qdoc16
-rw-r--r--doc/src/qt3d-contrib.qdoc16
-rw-r--r--doc/src/qt3d-examples.qdoc22
-rw-r--r--doc/src/qt3d-qml3d.qdoc10
-rw-r--r--doc/src/qt3d-troubleshooting.qdoc54
-rw-r--r--doc/src/tutorials/sceneformat.qdoc116
-rw-r--r--doc/src/tutorials/shaders.qdoc6
-rw-r--r--doc/src/tutorials/simpleobject.qdoc4
-rw-r--r--qt3d.pro6
-rw-r--r--qtc_packaging/debian_harmattan/README24
-rwxr-xr-xqtc_packaging/debian_harmattan/rules11
-rw-r--r--src/quick3d/qdeclarativeeffect.h2
-rw-r--r--src/quick3d/qdeclarativeitem3d.cpp2
-rw-r--r--src/quick3d/qdeclarativeitem3d.h2
-rw-r--r--src/quick3d/qdeclarativemesh.cpp2
-rw-r--r--src/quick3d/qdeclarativemesh.h2
-rw-r--r--src/quick3d/qdeclarativeview3d.h2
-rw-r--r--src/quick3d/qdeclarativeviewport.h2
-rw-r--r--src/quick3d/qt3dquickglobal.h2
-rwxr-xr-xsrc/scripts/build_mac_package.sh10
-rwxr-xr-xsrc/scripts/build_src_package.sh10
-rw-r--r--src/scripts/mac-install.rtf4
-rw-r--r--tests/manual/model3ds/README2
-rw-r--r--tests/systemtests/sys_quick3d.qtt2
35 files changed, 172 insertions, 287 deletions
diff --git a/README b/README
index 0ca5ef110..18d385988 100644
--- a/README
+++ b/README
@@ -1,16 +1,16 @@
This directory contains the Qt3D project for Qt 4.x:
- * QtQuick3D QML bindings and
+ * Qt3D QML bindings and
* Qt3D C++ APIs
-Building QtQuick3D
+Building Qt3D
==================
Check the building instructions in doc/src/qt3d-building.qdoc also available
online at: http://doc.qt.nokia.com/qt-quick3d-snapshot/qt3d-building.html
-Whats in QtQuick3D
+Whats in Qt3D
==================
Directory structure:
@@ -25,11 +25,11 @@ src/imports/
util/
Various utilities that are useful when working with Qt3D.
examples/
- Some examples of using QtQuick3D (QML bindings) and Qt3D (C++ API).
+ Some examples of using Qt3D (QML bindings) and Qt3D (C++ API).
demos/
- Some more complex demos of using QtQuick3D (QML bindings) and Qt3D (C++ API).
+ Some more complex demos of using Qt3D (QML bindings) and Qt3D (C++ API).
tests/auto/qml3d/
- Unit tests for the QtQuick3D bindings.
+ Unit tests for the Qt3D bindings.
tests/auto/threed/
Unit tests for the Qt3D C++ API
doc/
@@ -48,11 +48,11 @@ into "doc/html" in the build directory.
Packages
========
-This section is only for those developing QtQuick3D. Read on to discover how
+This section is only for those developing Qt3D. Read on to discover how
the building of packages works. This section is also important if you want to
-change how the structure of the QtQuick3D pro files work.
+change how the structure of the Qt3D pro files work.
-QtQuick3D is intended to be built in one of two ways:
+Qt3D is intended to be built in one of two ways:
1) Normal developer way:
qmake && make
@@ -60,22 +60,22 @@ QtQuick3D is intended to be built in one of two ways:
qmake CONFIG+=package && INSTALL_ROOT=tmp make install
In 1) the .pro files will cause the toolchain to place the libraries, plugins
-header files and other components of QtQuick3D directly into place, as part of
+header files and other components of Qt3D directly into place, as part of
the compile process. What does "in place" mean? Run "qmake -query" to see
the paths where the files are placed - QML plugins go in $$[QT_INSTALL_IMPORTS]
for example. In this mode, there is no need to run "make install" because the
files are already in their target destination. Here the "target destination"
means the Qt which is being built against.
-First note that QtQuick3D has to be installed into the target Qt. This is because
-QtQuick3D has QML plugins and resources, as well as shared libraries, all of which
+First note that Qt3D has to be installed into the target Qt. This is because
+Qt3D has QML plugins and resources, as well as shared libraries, all of which
must be resolved by the QMLViewer of the target Qt at runtime. Here where "qmake"
is referred to it means the qmake inside the target Qt. Since QtDeclarative
recommends using QMLViewer when developing and debugging QML Apps, in the developer
case - which is what Qt3D is for - it has to install directly into the target Qt.
In this mode 1) after the main library is compiled subsequent targets can simply
-resolve includes and link time dependencies by use of qt3d.prf and qtquick3d.prf.
+resolve includes and link time dependencies by use of qt3d.prf and qt3dquick.prf.
These two files are installed into the target Qt's makespecs/features directory
during the processing of the qt3d.pro file.
diff --git a/doc/config/qt-html-templates-online.qdocconf b/doc/config/qt-html-templates-online.qdocconf
index 9230e592e..0c3e0baf9 100644
--- a/doc/config/qt-html-templates-online.qdocconf
+++ b/doc/config/qt-html-templates-online.qdocconf
@@ -5,7 +5,7 @@ HTML.postheader = \
" <div class=\"content\"> \n" \
" <div id=\"nav-logo\">\n" \
" <a href=\"index.html\">Home</a></div>\n" \
- " <a href=\"index.html\" class=\"qtref\"><span>QtQuick3D Reference Documentation</span></a>\n" \
+ " <a href=\"index.html\" class=\"qtref\"><span>Qt3D Reference Documentation</span></a>\n" \
" <div id=\"narrowsearch\"></div>\n" \
" <div id=\"nav-topright\">\n" \
" <ul>\n" \
@@ -19,7 +19,7 @@ HTML.postheader = \
" </div>\n" \
" <div id=\"shortCut\">\n" \
" <ul>\n" \
- " <li class=\"shortCut-topleft-inactive\"><span><a href=\"index.html\">QtQuick3D</a></span></li>\n" \
+ " <li class=\"shortCut-topleft-inactive\"><span><a href=\"index.html\">Qt3D</a></span></li>\n" \
" </a></li>\n" \
" </ul>\n" \
" </div>\n" \
diff --git a/doc/config/qt-html-templates.qdocconf b/doc/config/qt-html-templates.qdocconf
index 7a78a0a0f..4af86ad75 100644
--- a/doc/config/qt-html-templates.qdocconf
+++ b/doc/config/qt-html-templates.qdocconf
@@ -3,7 +3,7 @@ include(qt-html-default-styles.qdocconf)
HTML.postheader = \
"<div class=\"header\" id=\"qtdocheader\">\n" \
" <div class=\"content\"> \n" \
- " <a href=\"index.html\" class=\"qtref\"><span>QtQuick3D Reference Documentation</span></a>\n" \
+ " <a href=\"index.html\" class=\"qtref\"><span>Qt3D Reference Documentation</span></a>\n" \
" </div>\n" \
" <div class=\"breadcrumb toolblock\">\n" \
" <ul>\n" \
diff --git a/doc/config/qt3d-project.qdocconf b/doc/config/qt3d-project.qdocconf
index 78f8fab1d..87998abf4 100644
--- a/doc/config/qt3d-project.qdocconf
+++ b/doc/config/qt3d-project.qdocconf
@@ -7,8 +7,8 @@ sourceencoding = UTF-8
outputencoding = UTF-8
naturallanguage = en_US
-project = QtQuick3D
-description = QtQuick3D Documentation
+project = Qt3D
+description = Qt3D Documentation
url = http://doc.qt.nokia.com/qtquick3d
language = Cpp
diff --git a/doc/src/acceptance/qt3d-acceptance.qdoc b/doc/src/acceptance/qt3d-acceptance.qdoc
index 01e2139b1..fd0a04b94 100644
--- a/doc/src/acceptance/qt3d-acceptance.qdoc
+++ b/doc/src/acceptance/qt3d-acceptance.qdoc
@@ -30,9 +30,6 @@
\title Acceptance tests for Qt3D
\keyword Acceptance
- As described in the \l{index.html}{Introduction} Qt3D is the C++ framework
- that underlies QtQuick3D.
-
This section of the documentation contains some recommended
acceptance tests for use when verifying that Qt3D has been
successfully ported to a new platform or device, and to
@@ -90,7 +87,7 @@
A pre-requisite for the acceptance tests is that Qt and Qt3D have
been built and installed in accordance with the
- \l{Building QtQuick3D}{build instructions}. In particular, Qt must
+ \l{Building Qt3D}{build instructions}. In particular, Qt must
be configured with OpenGL support and QGLWidget must be working.
First, run all unit tests on the platform or device and verify that
@@ -188,10 +185,10 @@
\c{QT_DEBUG_PLUGINS} environment variable to 1 to get extra
information about why the plug-in could not be loaded.
- \section1 QtQuick3D Verification
+ \section1 Qt3D Verification
- Run the QtQuick3D version of the bouncing
- \l{Teapot Example in QtQuick3D}{Teapot Example} using
+ Run the Qt3D version of the bouncing
+ \l{Teapot Example in Qt3D}{Teapot Example} using
"qmlviewer -opengl teapot-bounce.qml". The teapot should have a
shiny appearence (compared to the grey teapot above) and bounce
up and down:
@@ -201,13 +198,13 @@
It should be possible to rotate the teapot using the mouse
and keyboard.
- Note that when running QtQuick3D examples on a device that both the
+ Note that when running Qt3D examples on a device that both the
QML files and the model files must be copied to the device (the model
file is "teapot.bez" in the case of the bouncing teapot example).
\section1 Object picking
- Run the QtQuick3D \l{Tea Service Demo in QML}{Tea Service} demo
+ Run the Qt3D \l{Tea Service Demo in QML}{Tea Service} demo
with "qmlviewer -opengl teaservice.qml". Click on the teapot, teacups,
and teaspoons to make them jump up, and click on the teapot
spout and handle for other effects. This example tests object
diff --git a/doc/src/examples/basket.qdoc b/doc/src/examples/basket.qdoc
index 2b3f6ea95..ba99c87cf 100644
--- a/doc/src/examples/basket.qdoc
+++ b/doc/src/examples/basket.qdoc
@@ -29,9 +29,9 @@
\example quick3d/basket
\title Basket Example
- \section2 Basket in QtQuick3D
+ \section2 Basket in Qt3D
- The QtQuick3D version of the basket example is very similar in
+ The Qt3D version of the basket example is very similar in
structure to the C++ version above, but much simpler.
We start by defining a viewport with a specific camera position:
diff --git a/doc/src/examples/teapot-qml.qdoc b/doc/src/examples/teapot-qml.qdoc
index 1faeefc5e..d152b7275 100644
--- a/doc/src/examples/teapot-qml.qdoc
+++ b/doc/src/examples/teapot-qml.qdoc
@@ -27,9 +27,9 @@
/*!
\example quick3d/teapot_qml
- \title Teapot Example in QtQuick3D
+ \title Teapot Example in Qt3D
- This example shows to use QtQuick3D to display a teapot on
+ This example shows to use Qt3D to display a teapot on
the screen. The QML is fairly simple:
\snippet quick3d/teapot_qml/qml/teapot.qml 1
diff --git a/doc/src/examples/teapot.qdoc b/doc/src/examples/teapot.qdoc
index 27c75361f..acc0289cb 100644
--- a/doc/src/examples/teapot.qdoc
+++ b/doc/src/examples/teapot.qdoc
@@ -31,7 +31,7 @@
The Teapot example shows how Qt3D can be used to draw a simple
teapot object with a perspective camera view in C++. There is
- also a \l{Teapot Example in QtQuick3D}{QtQuick3D version} of the teapot
+ also a \l{Teapot Example in Qt3D}{Qt3D version} of the teapot
example.
We start by defining a class that inherits from QGLView, which
diff --git a/doc/src/images/qt3d-logo.png b/doc/src/images/qt3d-logo.png
deleted file mode 100644
index 1196826b2..000000000
--- a/doc/src/images/qt3d-logo.png
+++ /dev/null
Binary files differ
diff --git a/doc/src/index.qdoc b/doc/src/index.qdoc
index 7eaa3085e..eb43a213a 100644
--- a/doc/src/index.qdoc
+++ b/doc/src/index.qdoc
@@ -27,44 +27,52 @@
/*!
\page index.html
- \title QtQuick3D Reference Documentation
- \keyword QtQuick3D Reference Documentation
+ \title Qt3D Reference Documentation
+ \keyword Qt3D Reference Documentation
- \image qt3d-logo.png
+ \image icon-qt3d.png
- QtQuick3D adds 3D content to \l{http://qt.nokia.com/qtquick/}{Qt Quick's} cross-platform ability and coding power.
+ Qt 3D adds \bold{3D content} to \l{http://qt.nokia.com/qtquick/}{Qt Quick's} cross-platform ability and coding power.
Developers of fluid user interfaces can now enhance their applications with 3D
content in the same way icons and pixmaps would be used in a 2D application.
- QtQuick3D is a product resulting from the \l{http://doc.qt.nokia.com/qt3d-snapshot}{Qt3D project}. Qt3D is a set of powerful
- cross-platform C++ API's for 3D programming using OpenGL.
+ Qt3D comes with two libraries:
- QtQuick3D is made up of the QML bindings for Qt3D (called QML3D) plus
- Qt Creator integration, and other supporting tools. Qt3D may be used to
- extend QtQuick3D by creating new user-defined QML3D items using C++.
+ \table
+ \header
+ \o Library
+ \o API provided
+ \o Functionality
+ \o Useful For
+ \row
+ \o Qt3DQuick
+ \o QML API
+ \o QML bindings for Qt3D
+ \o Writing 3D apps in QML using declarative animations and techniques.
+ \row
+ \o Qt3D
+ \o C++ API
+ \o 3D rendering, scene-management and asset loading, plus more.
+ \o Extending QML3D and for writing 3D in Qt C++ instead of complex C-style OpenGL code.
+ \endtable
- OpenGL hardware was designed for 3D acceleration and QtQuick3D allows applications
- to utilise that 3D hardware fully.
+ The QML bindings create a whole new declarative way to write 3D applications, where the
+ naturally nested scopes of QML work to create 3D scene-graphs, and QML animations and easing-
+ curves can be easily applied to 3D objects. We call this \bold{QML3D}.
- QtQuick3D is the Qt Quick product for scripting 3D applications in QML. Apps can be
+ Thus QML3D is the Qt Quick tool for scripting 3D applications in QML. Apps can be
2D QML applications with a small amount of simple 3D content; through to complex
3D scenes, containing 3D assets - such as complex 3D models, and shader effects.
- In QtQuick3D scripts are written in QML, and rendered with the power of Qt & C++.
-
- Qt3D research continues and if the features you're looking for are not in QtQuick3D
- yet you may find them in the \l{http://doc.qt.nokia.com/qt3d-snapshot/index.html}{Qt3D research project}.
+ Qt3D research continues and if the features you're looking for are not in Qt3D
+ yet you may find them in the \l{http://qt.gitorious.org/qt-labs/qt3d}{Qt3D research project}.
- Check the Qt3D research project for upcoming features like \bold{stereoscopic support},
+ Check the Qt3D research project for features like \bold{stereoscopic support},
which will enable your programs to take advantage of special hardware that displays a different image to each eye.
- We are readying QtQuick3D for stereo support and in some places you may see references to it,
- however it is \bold{not supported yet}.
-
- QtQuick3D displays \bold{3D content} that is \bold{ready to be enhanced} by stereoscopic
- hardware, but out-of-the-box QtQuick3D works just fine on regular non-stereo displays
- and does not require special glasses or displays to use it.
+ We have done some work in Qt3D for stereo support and in some places you may see references to it,
+ however it is \bold{not supported currently}.
- See the \l{Tutorials and Examples} for an introduction to using QtQuick3D and Qt3D.
+ See the \l{Tutorials and Examples} for an introduction to using Qt3D.
\table 100%
\header
@@ -75,10 +83,9 @@
\o \list
\o \l{qt3d-building.html}{Building}
\o \l{qt3d-examples.html}{Tutorials and Examples}
- \o \l{Writing a scene format plug-in for Qt3D}{Scene format plug-ins}
\o \l{qt3d-contrib.html}{Contributing}
\o \l{qt3d-acceptance.html}{Acceptance tests}
- \o \l{qt3d-troubleshooting.html}{Troubleshooting Quick3D}
+ \o \l{qt3d-troubleshooting.html}{Troubleshooting Qt3D}
\endlist
\o \list
@@ -96,8 +103,8 @@
\o \list
\o \l{qt3d-all-classes.html}{All Classes}
\o \l{All Namespaces}{QGL Namespace}
- \o \l{QtQuick3D for Scripting 3D Apps in QML}{QtQuick3D Elements}
- \o \l{Stock Shapes for QtQuick3D}{QML/3D Stock Shapes}
+ \o \l{Qt3D for Scripting 3D Apps in QML}{QtQuick3D Elements}
+ \o \l{Stock Shapes for Qt3D}{QML/3D Stock Shapes}
\endlist
\endtable
*/
diff --git a/doc/src/qt3d-building.qdoc b/doc/src/qt3d-building.qdoc
index 28a325698..01809df19 100644
--- a/doc/src/qt3d-building.qdoc
+++ b/doc/src/qt3d-building.qdoc
@@ -68,7 +68,7 @@
More stable versions of the Qt3D source code is available as source
packages from \l{ftp://ftp.qt.nokia.com/qt3d/noarch}{Qt3D downloads page}.
- Just unzip or untar it into your \c{depot} directory.
+ Just unzip or untar it into your \c{source} directory.
\section1 Building Qt3D for Qt 4
@@ -114,7 +114,7 @@
\bold{Step 1} - Open the Qt3D project.
Choose \c{Open} from the \c{File} menu and navigate to the qt3d.pro project
- file \c {$HOME/depot/qt/quick3d/qt3d.pro}. Click \c{Open}.
+ file \c {$HOME/source/qt/qt3d/qt3d.pro}. Click \c{Open}.
\image build-qt3d-qtcreator-2.png
@@ -248,7 +248,7 @@
\code
$ mkdir -p $HOME/build/qt/qt3d && cd $HOME/build/qt/qt3d
- $ $HOME/build/qt/4.8/bin/qmake $HOME/depot/qt/qt3d/qt3d.pro
+ $ $HOME/build/qt/4.8/bin/qmake $HOME/source/qt/qt3d/qt3d.pro
$ make -j 4
\endcode
@@ -261,7 +261,7 @@
\code
mkdir \build\qt\qt3d && cd \build\qt\qt3d
- qmake \depot\qt\quick3d\qt3d.pro
+ qmake \source\qt\qt3d\qt3d.pro
nmake
\endcode
@@ -272,8 +272,8 @@
On Symbian (with RVCT) those commands look like this:
\code
- mkdir C:\sources\qt\qt3d
- cd C:\sources\qt\qt3d
+ mkdir C:\source\qt\qt3d
+ cd C:\source\qt\qt3d
qmake CONFIG+=old_importer
sbs -c armv5_urel
cd devices\symbian
@@ -281,10 +281,10 @@
runonphone --sis Qt3D.sis
\endcode
- Once you have built Qt3D, you can run the "teapot" example:
+ Once you have built Qt 3D, you can run the "teapot" example:
\code
- $ cd $HOME/build/qt/quick3d
+ $ cd $HOME/build/qt/qt3d
$ bin/teapot
\endcode
diff --git a/doc/src/qt3d-contrib.qdoc b/doc/src/qt3d-contrib.qdoc
index 5b7fabdc3..ac0305cfb 100644
--- a/doc/src/qt3d-contrib.qdoc
+++ b/doc/src/qt3d-contrib.qdoc
@@ -27,28 +27,24 @@
/*!
\page qt3d-contrib.html
- \title Contributing to QtQuick3D and Qt3D
+ \title Contributing to Qt3D and Qt3D
\keyword Contributing to Qt3D
- QtQuick3D and Qt3D are developed primarily in the Brisbane office of Qt
+ Qt3D and Qt3D are developed primarily in the Brisbane office of Qt
Development Frameworks, but anyone is welcome to join the effort with
patches, new examples, and major feature development.
- Qt3D research may be a better place to contribute as the QtQuick3D has a strong
- product focus. Check the Qt3D \l{http://doc.qt.nokia.com/qt3d-snapshot/qt3d-contrib.html}{contributions page}.
-
Jump on the IRC channel at #qt-3d on irc.freenode.net, or join our qt3d
mailing list at \l{http://lists.trolltech.com/mailman/listinfo/qt-3d}.
All contributions need to conform with the
\l{http://qt.gitorious.org/qt/pages/QtContributionGuidelines}{Qt Contribution Model Guidelines}.
- The source for QtQuick3D is hosted on Gitorious at
- \l{http://qt.gitorious.org/qt-labs/quick3d}.
+ See our \l{Building Qt3D for Qt 4}{building instructions} for details on how
+ to obtain Qt3D sources and build the project.
Bugs can be reported against the "Qt3D" component of the "Qt" project
- at \l{http://bugreports.qt.nokia.com/}.
-
+ at \l{http://bugreports.qt-project.org/}.
- \l{index.html}{Return to the main QtQuick3D page}.
+ \l{index.html}{Return to the main Qt3D page}.
*/
diff --git a/doc/src/qt3d-examples.qdoc b/doc/src/qt3d-examples.qdoc
index 8ed8bb735..0141a9bf2 100644
--- a/doc/src/qt3d-examples.qdoc
+++ b/doc/src/qt3d-examples.qdoc
@@ -30,18 +30,18 @@
\title Tutorials and Examples
\keyword Tutorials and Examples
- Building 3D applications in QML with QtQuick3D:
+ Building 3D applications in QML with Qt3D:
\list
- \o \l{Teapot Example in QtQuick3D}{Hello Teapot} in QtQuick3D
- \o \l{quick3d/basket#Basket in QtQuick3D}{Basket} in QtQuick3D
- \o \l{Object Effects}{Cube} in QtQuick3D
- \o \l{Monkey God in QML}{Monkey God} in QtQuick3D
- \o \l{Tea Service Demo in QML}{Tea Service} in QtQuick3D
- \o \l{Using GLSL shaders in QtQuick3D}
+ \o \l{Teapot Example in Qt3D}{Hello Teapot}
+ \o \l{quick3d/basket#Basket in Qt3D}{Basket}
+ \o \l{Object Effects}{Cube}
+ \o \l{Monkey God in QML}{Monkey God}
+ \o \l{Tea Service Demo in QML}{Tea Service}
+ \o \l{Using GLSL shaders in Qt3D}
\endlist
- Using C++ to extend QtQuick3D and to build applications with Qt3D:
+ Using the Qt3D C++ API:
\list
\o \l{Teapot Example}{Hello Teapot} - drawing a basic object in 3D.
@@ -52,12 +52,6 @@
\o \l{qt3d/shapes}{Shapes} - paints all of the basic OpenGL shapes.
\endlist
- Other topics:
-
- \list
- \o \l{Scene Format Plugin}{Writing a scene format plug-in for Qt3D}
- \endlist
-
\l{index.html}{Return to the main Qt3D page}.
*/
diff --git a/doc/src/qt3d-qml3d.qdoc b/doc/src/qt3d-qml3d.qdoc
index 3a620f567..888789fb6 100644
--- a/doc/src/qt3d-qml3d.qdoc
+++ b/doc/src/qt3d-qml3d.qdoc
@@ -27,24 +27,24 @@
/*!
\group qt3d::qml3d
-\title QtQuick3D for Scripting 3D Apps in QML
-\keyword QtQuick3D QML
+\title Qt3D for Scripting 3D Apps in QML
+\keyword Qt3D QML
The following QML elements are provided by the \c{Qt3D} namespace
for importing 3D elements into QML applications:
\generatelist{related}
-See the \l{Teapot Example in QtQuick3D}{Teapot} example for an introduction
+See the \l{Teapot Example in Qt3D}{Teapot} example for an introduction
to using these elements.
-QtQuick3D also provides some \l{Stock Shapes for QtQuick3D}{stock shapes}
+Qt3D also provides some \l{Stock Shapes for Qt3D}{stock shapes}
in the \c{Qt3D.Shapes} namespace as convenience elements.
*/
/*!
\group qt3d::qml3d::shapes
-\title Stock Shapes for QtQuick3D
+\title Stock Shapes for Qt3D
The following QML elements are provided by the \c{Qt3D.Shapes} namespace
as convenience elements:
diff --git a/doc/src/qt3d-troubleshooting.qdoc b/doc/src/qt3d-troubleshooting.qdoc
index e02422fb5..b0b42861a 100644
--- a/doc/src/qt3d-troubleshooting.qdoc
+++ b/doc/src/qt3d-troubleshooting.qdoc
@@ -27,10 +27,10 @@
/*!
\page qt3d-troubleshooting.html
- \title QtQuick3D Troubleshooting Guide
- \keyword Building QML QtQuick3D
+ \title Qt3D Troubleshooting Guide
+ \keyword Building QML Qt3D
- Quick3D has been developed with the intention of supporting a variety
+ Qt 3D has been developed with the intention of supporting a variety
of platforms and systems, and in doing so leverages the plugin and
import architecture used by Qt.
@@ -38,7 +38,7 @@
the Qt plugin architecture, however, which can cause runtime problems to
occasionally arise.
- \section1 Common Quick3D Problems
+ \section1 Common Qt 3D Problems
\section2 PROBLEM 1: I Can't See Warnings from my QML/3D Application
@@ -71,7 +71,7 @@
\section2 PROBLEM 2: Qt3D Plugin File Not Found
- By far the most prevalant problems encountered by Quick3D newcomers are
+ By far the most prevalant problems encountered by Qt 3D newcomers are
those relating to inability for an application to find the correct plugins
at runtime.
@@ -106,7 +106,7 @@
messages similar to the following:
\code
- file:///path/to/quick3d/app.qml:10:1: plugin cannot be loaded for module "Qt3D": Cannot load library C:/path/to/Qt/imports/qthreedqmlplugin.dll: The specified module could not be found.
+ file:///path/to/qt3d/app.qml:10:1: plugin cannot be loaded for module "Qt3D": Cannot load library C:/path/to/Qt/imports/qthreedqmlplugin.dll: The specified module could not be found.
\endcode
To resolve this problem try each of the Resolution Actions listed, one at
@@ -141,11 +141,11 @@
\section2 PROBLEM 7: Case mis-match on loading QML plugins
- You get a blank screen when the Qt Quick 3D application runs. The debug output
+ You get a blank screen when the Qt 3D application runs. The debug output
(see Problem 1 above) reveals a message similar to
\code
- Starting C:\Qt\4.7.3\bin\qmlviewer.exe -I C:/Qt/4.7.3/imports C:/Qt/4.7.3/quick3d/bin/resources/examples/basket_qml/qml/basket.qml
- C:/Qt/4.7.3/quick3d/bin/resources/examples/basket_qml/qml/basket.qml: File name case mismatch
+ Starting C:\Qt\4.8.1\bin\qmlviewer.exe -I C:/Qt/4.8.1/imports C:/Qt/4.8.1/qt3d/bin/resources/examples/basket_qml/qml/basket.qml
+ C:/Qt/4.8.1/qt3d/bin/resources/examples/basket_qml/qml/basket.qml: File name case mismatch
\endcode
This issue can occur when a custom install directory for Qt is used, which does not
@@ -164,22 +164,22 @@
\section1 Resolution Actions
- \section2 ACTION 1: Ensure that Quick3D is Building Correctly
+ \section2 ACTION 1: Ensure that Qt 3D is Building Correctly
As obvious as this sounds, it is sometimes the case that a problem is
- caused simply by one of the runtime libraries or plugins for Quick3D
+ caused simply by one of the runtime libraries or plugins for Qt 3D
failing to build, even while the user's application itself builds without
error.
- Ensure that all of the components of Quick3D have built without error
+ Ensure that all of the components of Qt 3D have built without error
before attempting further resolution actions.
\section2 ACTION 2: Ensure Import Files Are Correctly Located
- Ensure that the Quick3D import libraries are in the directory specified by
+ Ensure that the Qt 3D import libraries are in the directory specified by
the QtQuick import path.
- The core Quick3D import directory is: \c{imports\Qt3D} in the directory
+ The core Qt 3D import directory is: \c{imports\Qt3D} in the directory
where Qt is installed.
This directory should contain the files as shown in the following diagram:
@@ -190,14 +190,14 @@
\c{C:\Qt\4.7.3}.
If these files are not in the correct locations copy them manually into the
- specified locations and retry your Quick3D application before moving on to
+ specified locations and retry your Qt 3D application before moving on to
other fixes. The dll's should have been built as part of your build process
and the other files are shipped in the source tree, and can be simply copied
over if somehow the build process has failed to do this.
\section2 ACTION 3: Ensure Qt3D Libraries Are Correctly Located
- Ensure that the Quick3D libraries can be found by the application. The
+ Ensure that the Qt 3D libraries can be found by the application. The
files that should be found are:
\list
@@ -223,10 +223,10 @@
\section2 ACTION 4: Ensure Additional Plugin Libraries Are Correctly Located
- Ensure that the Quick3D plugin libraries are in the directory specified by
+ Ensure that the Qt 3D plugin libraries are in the directory specified by
the QtQuick plugins path.
- The Quick3D scene format plugins (which are responsible for loading model files)
+ The Qt 3D scene format plugins (which are responsible for loading model files)
should be found in:
\code
@@ -240,7 +240,7 @@
\o qscenebezier4.dll
\endlist
- Additional Quick3D image format plugins (which are responsible for loading some
+ Additional Qt 3D image format plugins (which are responsible for loading some
image files) should be found in:
\code
@@ -254,25 +254,25 @@
\endlist
If these files are not in the correct locations copy them manually into the
- specified locations and retry your Quick3D application before moving on to
+ specified locations and retry your Qt 3D application before moving on to
other fixes.
\section2 ACTION 5: Check Your Build Configuration
- It is possible that Quick3D libraries which have been built against a given
+ It is possible that Qt 3D libraries which have been built against a given
set of Qt libraries have problems when used with another build of Qt.
This may be resolved by trying each of the following:
\list
- \o Ensure that the Qt and Quick3D libraries use the same toolchain/compiler.
- \o Ensure that the Qt Configuration used to build Quick3D matches that used in
+ \o Ensure that the Qt and Qt 3D libraries use the same toolchain/compiler.
+ \o Ensure that the Qt Configuration used to build Qt 3D matches that used in
your runtime Qt libraries.
- \o Ensure that the Qt used to build Quick3D and the Qt runtimes are both either
+ \o Ensure that the Qt used to build Qt 3D and the Qt runtimes are both either
Debug or Release, not a mixture of both.
\endlist
- After making this change, retry your Quick3D application before implementing
+ After making this change, retry your Qt 3D application before implementing
other troubleshooting tips.
\section2 ACTION 6: Clear the Plugin Cache
@@ -281,7 +281,7 @@
cache is stored through QSettings, and so is platform independent.
It is possible that obselete plugin data for an older version of your Qt3D
- plugins could be causing your Quick3D applications to fail.
+ plugins could be causing your Qt 3D applications to fail.
On Windows the entries in the plugin cache are stored in the registry, and
typically begin with one of the following strings:
@@ -291,5 +291,5 @@
HKEY_CURRENT_USER\Software\Trolltech\OrganizationDefaults\Qt Plugin Cache 4.2.false
\endcode
- Delete these entries and retry your Quick3D application.
+ Delete these entries and retry your Qt 3D application.
*/
diff --git a/doc/src/tutorials/sceneformat.qdoc b/doc/src/tutorials/sceneformat.qdoc
deleted file mode 100644
index ac8754ab7..000000000
--- a/doc/src/tutorials/sceneformat.qdoc
+++ /dev/null
@@ -1,116 +0,0 @@
-/****************************************************************************
-**
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
-**
-** This file is part of the Qt3D documentation of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:FDL$
-** GNU Free Documentation License
-** Alternatively, this file may be used under the terms of the GNU Free
-** Documentation License version 1.3 as published by the Free Software
-** Foundation and appearing in the file included in the packaging of
-** this file.
-**
-** Other Usage
-** Alternatively, this file may be used in accordance with the terms
-** and conditions contained in a signed written agreement between you
-** and Nokia.
-**
-**
-**
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
-
-/*!
- \title Writing a scene format plug-in for Qt3D
- \keyword Scene Format Plugin
- \example sceneformats/obj
-
- Scene format plugins are used to load external 3D model file
- formats like \bold 3DS, \bold obj, and so on. In this tutorial we will
- do a walk-through of the \bold obj scene format plugin to
- demonstrate what is required to add a new format to Qt3D.
-
- Models are loaded by QGLAbstractScene::loadScene(), which locates
- a suitable plug-in for the format, and then asks the plug-in to
- parse the data and create a QGLAbstractScene object that describes
- the 3D objects in the scene.
-
- We start by declaring an instance of QGLSceneFormatPlugin and
- arranging for it to be registered with the Qt plug-in system:
-
- \snippet sceneformats/obj/main.cpp 1
- \snippet sceneformats/obj/main.cpp 4
-
- The two functions we need to implement are
- \l{QGLSceneFormatPlugin::keys()}{keys()} and
- \l{QGLSceneFormatPlugin::create()}{create()}. The first of these
- returns a lower-case list of the file extensions and MIME types
- that are supported by the plug-in:
-
- \snippet sceneformats/obj/main.cpp 2
-
- The create function is called to create the QGLSceneFormatHandler
- which is used to load the model data:
-
- \snippet sceneformats/obj/main.cpp 3
-
- The create function is passed the QIODevice for the data,
- the URL of where the data was found, and the chosen format.
- These parameters can be used by the plug-in to decide which
- handler to return if multiple formats are supported by
- the plug-in. In the case of obj, we always return the same
- handler so we don't need to inspect the passed parameters.
-
- QGLAbstractScene::loadScene() will set the parameters on
- the QGLSceneFormatHandler object and then call
- \l{QGLSceneFormatHandler::read()}{read()}:
-
- \snippet sceneformats/obj/qglobjscenehandler.h 1
- \dots
- \snippet sceneformats/obj/qglobjscenehandler.h 2
-
- The read function will typically construct a QGLBuilder
- for the geometry in the scene and then parse all of the objects,
- materials, textures, and so on. Ultimately, it needs to produce a
- QGLAbstractScene object, populated with QGLSceneNode instances
- for each of the objects in the model file. In our case, we create
- an instance of \c QGLObjScene:
-
- \snippet sceneformats/obj/qglobjscene.h 1
- \dots
- \snippet sceneformats/obj/qglobjscene.h 2
- \dots
- \snippet sceneformats/obj/qglobjscene.h 3
-
- The most important function is the override for
- QGLAbstractScene::objects(), which allows the rest of Qt3D
- to query the full list of objects in the model file.
- The scene object can also override QGLAbstractScene::object()
- if it has an efficient method to quickly look up an object by name.
-
- The scene should also override QGLAbstractScene::mainNode()
- to return the main mesh node in the scene. Usually this is
- the first element in the list returned by QGLAbstractScene::objects()
- but doesn't have to be.
-
- Note: the plug-in does not need to use QGLBuilder and the
- other Qt3D classes to load the model if it doesn't want to.
- It can instantiate subclasses of QGLSceneNode that override
- the draw() method and draws the object using whatever technique
- the plug-in chooses. It just needs to leave the OpenGL state
- in the condition that it found it so that other parts of Qt3D
- will not be confused.
-
- Once you have written a plug-in for your new format, you should
- install it into \c{$QTDIR/plugins/sceneformats}. You can test it
- by running the \c{modelviewer} program and trying to load models
- in your new format. When debugging, it can be useful to set the
- \c{QT_DEBUG_PLUGINS} environment variable to 1.
-
- \l{qt3d-examples.html}{Return to the main Tutorials page}.
-*/
diff --git a/doc/src/tutorials/shaders.qdoc b/doc/src/tutorials/shaders.qdoc
index 13c667464..239430617 100644
--- a/doc/src/tutorials/shaders.qdoc
+++ b/doc/src/tutorials/shaders.qdoc
@@ -26,12 +26,12 @@
****************************************************************************/
/*!
- \title Using GLSL shaders in QtQuick3D
+ \title Using GLSL shaders in Qt3D
\example quick3d/shaders
In this tutorial, we will show how to apply QML property animations to
- GLSL shaders in a QtQuick3D application.
+ GLSL shaders in a Qt3D application.
Starting with a relatively simple shader program, we are going to
manipulate various parameters to explain how both the shader and the QML
@@ -52,7 +52,7 @@
</table>
\endraw
- At the highest level, shaders in QtQuick3D are created using the ShaderProgram
+ At the highest level, shaders in Qt3D are created using the ShaderProgram
element. The ShaderProgram element in this example has the id \a program,
and applying it to the teapot is as simple as assigning it to the \c effect
property of an Item3D derived element.
diff --git a/doc/src/tutorials/simpleobject.qdoc b/doc/src/tutorials/simpleobject.qdoc
index 6e8c5338a..52dc2e6cc 100644
--- a/doc/src/tutorials/simpleobject.qdoc
+++ b/doc/src/tutorials/simpleobject.qdoc
@@ -34,9 +34,9 @@
simple cube object to demonstrate how to modify the QGLPainter
state to achieve different effects.
- \section2 Cube in QtQuick3D
+ \section2 Cube in Qt3D
- It is quite simple to achieve these effects in QtQuick3D:
+ It is quite simple to achieve these effects in Qt3D:
\snippet quick3d/cube/qml/cube.qml 1
diff --git a/qt3d.pro b/qt3d.pro
index cda69359e..2679424b7 100644
--- a/qt3d.pro
+++ b/qt3d.pro
@@ -13,14 +13,14 @@ include(doc/doc.pri)
# We need opengl, minimum es2 or desktop
!contains(QT_CONFIG, opengl) {
- error(QtQuick3D requires OpenGL!)
+ error(Qt3D requires OpenGL!)
}
contains(QT_CONFIG, opengles1) {
- error(QtQuick3D does not support OpenGL ES 1!)
+ error(Qt3D does not support OpenGL ES 1!)
}
# We need qt declarative
!contains(QT_CONFIG, declarative) {
- error(QtQuick3D requires Qt Declarative!)
+ error(Qt3D requires Qt Declarative!)
}
# Install qt3d.prf into the Qt mkspecs so that "CONFIG += qt3d"
diff --git a/qtc_packaging/debian_harmattan/README b/qtc_packaging/debian_harmattan/README
index c41653d01..904d60d54 100644
--- a/qtc_packaging/debian_harmattan/README
+++ b/qtc_packaging/debian_harmattan/README
@@ -1,16 +1,16 @@
This is the Qt Quick 3D project:
- * QtQuick3D QML bindings and
+ * Qt3D QML bindings and
* Qt3D C++ APIs
-Building QtQuick3D
+Building Qt3D
==================
Check the building instructions in doc/src/qt3d-building.qdoc also available
online at: http://doc.qt.nokia.com/qt-quick3d-snapshot/qt3d-building.html
-Whats in QtQuick3D
+Whats in Qt3D
==================
Directory structure:
@@ -25,11 +25,11 @@ src/imports/
util/
Various utilities that are useful when working with Qt3D.
examples/
- Some examples of using QtQuick3D (QML bindings) and Qt3D (C++ API).
+ Some examples of using Qt3D (QML bindings) and Qt3D (C++ API).
demos/
Some more complex demos of using QtQuiick3D (QML bindings) and Qt3D (C++ API).
tests/auto/qml3d/
- Unit tests for the QtQuick3D bindings.
+ Unit tests for the Qt3D bindings.
tests/auto/threed/
Unit tests for the Qt3D C++ API
doc/
@@ -48,11 +48,11 @@ into "doc/html" in the build directory.
Packages
========
-This section is only for those developing QtQuick3D. Read on to discover how
+This section is only for those developing Qt3D. Read on to discover how
the building of packages works. This section is also important if you want to
-change how the structure of the QtQuick3D pro files work.
+change how the structure of the Qt3D pro files work.
-QtQuick3D is intended to be built in one of two ways:
+Qt3D is intended to be built in one of two ways:
1) Normal developer way:
qmake && make
@@ -60,22 +60,22 @@ QtQuick3D is intended to be built in one of two ways:
qmake CONFIG+=package && INSTALL_ROOT=tmp make install
In 1) the .pro files will cause the toolchain to place the libraries, plugins
-header files and other components of QtQuick3D directly into place, as part of
+header files and other components of Qt3D directly into place, as part of
the compile process. What does "in place" mean? Run "qmake -query" to see
the paths where the files are placed - QML plugins go in $$[QT_INSTALL_IMPORTS]
for example. In this mode, there is no need to run "make install" because the
files are already in their target destination. Here the "target destination"
means the Qt which is being built against.
-First note that QtQuick3D has to be installed into the target Qt. This is because
-QtQuick3D has QML plugins and resources, as well as shared libraries, all of which
+First note that Qt3D has to be installed into the target Qt. This is because
+Qt3D has QML plugins and resources, as well as shared libraries, all of which
must be resolved by the QMLViewer of the target Qt at runtime. Here where "qmake"
is referred to it means the qmake inside the target Qt. Since QtDeclarative
recommends using QMLViewer when developing and debugging QML Apps, in the developer
case - which is what Qt3D is for - it has to install directly into the target Qt.
In this mode 1) after the main library is compiled subsequent targets can simply
-resolve includes and link time dependencies by use of qt3d.prf and qtquick3d.prf.
+resolve includes and link time dependencies by use of qt3d.prf and qt3dquick.prf.
These two files are installed into the target Qt's makespecs/features directory
during the processing of the qt3d.pro file.
diff --git a/qtc_packaging/debian_harmattan/rules b/qtc_packaging/debian_harmattan/rules
index dc4bbaeb3..e7255c6fc 100755
--- a/qtc_packaging/debian_harmattan/rules
+++ b/qtc_packaging/debian_harmattan/rules
@@ -18,8 +18,13 @@
#
# ### Step 2: set up to use the Madde build environment - eg if Madde is in your home under QtSDK:
# export MADDE=$HOME/QtSDK/Madde
-# export PATH=$MADDE/targets/harmattan-platform-api/bin:$MADDE/bin:$MADDE/madlib:$MADDE/madbin:$PATH
+#
+# **** check that this directory contains the version of qmake & tools for your SDK:
+# export TARGET_API=$MADDE/targets/harmattan_10.2011.34-1_rt1.2/bin
+# export PATH=$TARGET_API:$MADDE/bin:$MADDE/madlib:$MADDE/madbin:$PATH
# export PERL5LIB=$MADDE/madlib/perl5
+#
+# **** check that this directory contains a sysroot for your N9 in your SDK
# export SYSROOT_DIR=$MADDE/sysroots/harmattan-meego-arm-sysroot-1122-slim
#
# ### Step 3: copy all the stuff across - cannot shadow build (probably don't want git)
@@ -54,7 +59,7 @@ DEB_MAKE_INVOKE := $(MAKE) $(PARALLEL_MAKEFLAGS)
configure: configure-stamp
configure-stamp:
dh_testdir
- qmake -spec linux-g++-maemo qt3d.pro CONFIG+=qtc_harmattan # Uncomment this line for use without Qt Creator
+ # qmake -spec linux-g++-maemo qt3d.pro CONFIG+=qtc_harmattan # Uncomment this line for use without Qt Creator
touch configure-stamp
build: build-stamp
@@ -63,7 +68,7 @@ build-stamp: configure-stamp
dh_testdir
# Add here commands to compile the package.
- $(DEB_MAKE_INVOKE) # Uncomment this line for use without Qt Creator
+ # $(DEB_MAKE_INVOKE) # Uncomment this line for use without Qt Creator
#docbook-to-man debian/quick3d.sgml > quick3d.1
touch $@
diff --git a/src/quick3d/qdeclarativeeffect.h b/src/quick3d/qdeclarativeeffect.h
index 9d248b71e..88b5653f6 100644
--- a/src/quick3d/qdeclarativeeffect.h
+++ b/src/quick3d/qdeclarativeeffect.h
@@ -56,7 +56,7 @@ QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE
-QT_MODULE(QtQuick3D)
+QT_MODULE(Qt3DQuick)
class QDeclarativeEffectPrivate;
class QGLPainter;
diff --git a/src/quick3d/qdeclarativeitem3d.cpp b/src/quick3d/qdeclarativeitem3d.cpp
index ca44b9da1..bac76aa4b 100644
--- a/src/quick3d/qdeclarativeitem3d.cpp
+++ b/src/quick3d/qdeclarativeitem3d.cpp
@@ -793,7 +793,7 @@ void QDeclarativeItem3D::setInheritEvents(bool inherit)
\qmlproperty Mesh Item3D::mesh
Objects in most 3D environments are almost invariably defined as meshes - sets of
- vertices which when linked as polygons form a recognisable 3D object. QtQuick3D currently
+ vertices which when linked as polygons form a recognisable 3D object. Qt3D currently
supports a number of these \i {scene formats}, including \i {.obj} file, bezier patches
\i {(.bez)}, and \i {.3ds} files.
diff --git a/src/quick3d/qdeclarativeitem3d.h b/src/quick3d/qdeclarativeitem3d.h
index ca55485ae..6929b5d5a 100644
--- a/src/quick3d/qdeclarativeitem3d.h
+++ b/src/quick3d/qdeclarativeitem3d.h
@@ -58,6 +58,8 @@ QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE
+QT_MODULE(Qt3DQuick)
+
class QDeclarativeItem3DPrivate;
class QDeclarativeMesh;
class QDeclarativeEffect;
diff --git a/src/quick3d/qdeclarativemesh.cpp b/src/quick3d/qdeclarativemesh.cpp
index 9460fcaaa..93cf348a4 100644
--- a/src/quick3d/qdeclarativemesh.cpp
+++ b/src/quick3d/qdeclarativemesh.cpp
@@ -175,7 +175,7 @@ QDeclarativeMesh::~QDeclarativeMesh()
transformations, textures, and so on. This data is generally stored in files and
specified via the source property.
- Source files can be of any type supported by QtQuick3D. The types of file currently
+ Source files can be of any type supported by Qt3D. The types of file currently
supported can be found in the \c sceneFormat plugins, with \i .3ds, \i .bez, \i. obj
files currently being supported.
diff --git a/src/quick3d/qdeclarativemesh.h b/src/quick3d/qdeclarativemesh.h
index 934599dd8..9f8675033 100644
--- a/src/quick3d/qdeclarativemesh.h
+++ b/src/quick3d/qdeclarativemesh.h
@@ -57,7 +57,7 @@ QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE
-QT_MODULE(QtQuick3D)
+QT_MODULE(Qt3DQuick)
class QDeclarativeMeshPrivate;
class QGLAbstractScene;
diff --git a/src/quick3d/qdeclarativeview3d.h b/src/quick3d/qdeclarativeview3d.h
index 5830aa2cb..bca718d2d 100644
--- a/src/quick3d/qdeclarativeview3d.h
+++ b/src/quick3d/qdeclarativeview3d.h
@@ -49,7 +49,7 @@ QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE
-QT_MODULE(QtQuick3D)
+QT_MODULE(Qt3DQuick)
class QGLWidget;
diff --git a/src/quick3d/qdeclarativeviewport.h b/src/quick3d/qdeclarativeviewport.h
index 2bc712651..315100175 100644
--- a/src/quick3d/qdeclarativeviewport.h
+++ b/src/quick3d/qdeclarativeviewport.h
@@ -49,7 +49,7 @@ QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE
-QT_MODULE(QtQuick3D)
+QT_MODULE(Qt3DQuick)
class QDeclarativeItem3D;
diff --git a/src/quick3d/qt3dquickglobal.h b/src/quick3d/qt3dquickglobal.h
index cc232ae2a..b9a4ac80d 100644
--- a/src/quick3d/qt3dquickglobal.h
+++ b/src/quick3d/qt3dquickglobal.h
@@ -44,7 +44,7 @@
#include <QtCore/qglobal.h>
-QT_LICENSED_MODULE(QtQuick3D)
+QT_LICENSED_MODULE(Qt3DQuick)
#if defined(Q_OS_WIN) || defined(Q_OS_SYMBIAN)
# if defined(QT_NODLL)
# undef QT_MAKEDLL
diff --git a/src/scripts/build_mac_package.sh b/src/scripts/build_mac_package.sh
index c38d1674c..b6888fc8c 100755
--- a/src/scripts/build_mac_package.sh
+++ b/src/scripts/build_mac_package.sh
@@ -42,7 +42,7 @@
set -e
-APP=QtQuick3D
+APP=Qt3D
PRO=qt3d.pro
@@ -71,7 +71,7 @@ mkdir -p $DEV_PKG_ROOT
INSTALL_ROOT=$PWD/dist/dev/Pkg_Root make $(JOBS) install
make docs
-DOC_LOC="Developer/Documentation/QtQuick3D"
+DOC_LOC="Developer/Documentation/Qt3D"
mkdir -p "$DEV_PKG_ROOT/$DOC_LOC"
mv doc/html "$DEV_PKG_ROOT/$DOC_LOC"
@@ -87,7 +87,7 @@ XMPL_PKG_RES="$DIST/$XMPL/Resources"
mkdir -p $XMPL_PKG_RES
cp src/scripts/mac_installer_background.png $XMPL_PKG_RES/background.png
-XMPL_LOC="Applications/QtQuick3D Examples"
+XMPL_LOC="Applications/Qt3D Examples"
mkdir -p "${XMPL_PKG_ROOT}/$XMPL_LOC"
mv "${DEV_PKG_ROOT}/Developer/Tools/Qt" "${XMPL_PKG_ROOT}/$XMPL_LOC"
@@ -104,14 +104,14 @@ PKGMGR="/Developer/Applications/Utilities/PackageMaker.app/Contents/MacOS/Packag
## TODO: create VolumeCheck script to ensure 4.7.2 is installed
PKG="${RELEASE_DIR}/${APP}-${VER}-${DEV}.pkg"
$PKGMGR --root "$DEV_PKG_ROOT" \
- --id "com.nokia.qtquick3d.${DEV}" \
+ --id "com.nokia.quick3d.${DEV}" \
--resources "$DEV_PKG_RES" \
--title "Core Developer Tools" \
--target 10.5 --version "$VER" --verbose --out "$PKG"
PKG="${RELEASE_DIR}/${APP}-${VER}-${XMPL}.pkg"
$PKGMGR --root "$XMPL_PKG_ROOT" \
- --id "com.nokia.qtquick3d.${XMPL}" \
+ --id "com.nokia.quick3d.${XMPL}" \
--resources "$XMPL_PKG_RES" \
--title "Example Applications" \
--target 10.5 --version "$VER" --verbose --out "$PKG"
diff --git a/src/scripts/build_src_package.sh b/src/scripts/build_src_package.sh
index 8d9260b36..77caa5884 100755
--- a/src/scripts/build_src_package.sh
+++ b/src/scripts/build_src_package.sh
@@ -74,14 +74,14 @@ test -f qt3d.pro || usage
BRANCH=$1
VERSION=$2
echo "Creating tar archive..."
-git archive --format=tar --prefix=qtquick3d-${VERSION}-src/ ${BRANCH} | gzip > ../qtquick3d-${VERSION}-src.tar.gz || exit 1
+git archive --format=tar --prefix=quick3d-${VERSION}-src/ ${BRANCH} | gzip > ../quick3d-${VERSION}-src.tar.gz || exit 1
echo "Creating zip archive..."
-git archive --format=zip --prefix=qtquick3d-${VERSION}-src/ ${BRANCH} > ../qtquick3d-${VERSION}-src.zip || exit 1
+git archive --format=zip --prefix=quick3d-${VERSION}-src/ ${BRANCH} > ../quick3d-${VERSION}-src.zip || exit 1
echo "Creating documentation..."
rm -r -f doc/html
qmake qt3d.pro -spec macx-g++ CONFIG+=package >/dev/null || exit 1
make docs || exit 1
cd doc
-cp -r html qtquick3d-${VERSION}
-zip -r ../../qtquick3d-${VERSION}-doc.zip qtquick3d-${VERSION} >/dev/null
-rm -r qtquick3d-${VERSION}
+cp -r html quick3d-${VERSION}
+zip -r ../../quick3d-${VERSION}-doc.zip quick3d-${VERSION} >/dev/null
+rm -r quick3d-${VERSION}
diff --git a/src/scripts/mac-install.rtf b/src/scripts/mac-install.rtf
index f596b71c7..20d5dd9fd 100644
--- a/src/scripts/mac-install.rtf
+++ b/src/scripts/mac-install.rtf
@@ -5,9 +5,9 @@
\deftab720
\pard\pardeftab720\sl276\slmult1\sa200\ql\qnatural
-\f0\b\fs22 \cf0 Thanks for installing QtQuick3D! \
+\f0\b\fs22 \cf0 Thanks for installing Qt3D! \
-\b0 To create applications with QtQuick3D simply open QtCreator, and ensure that your new project uses the "Qt in Path" under the "Auto-detected" section of the Qt Versions. See the Qt Creator's Preference pane and choose the "Qt 4" tab.\
+\b0 To create applications with Qt3D simply open QtCreator, and ensure that your new project uses the "Qt in Path" under the "Auto-detected" section of the Qt Versions. See the Qt Creator's Preference pane and choose the "Qt 4" tab.\
You can also compile applications from the command line by using the command "quake".\
\
} \ No newline at end of file
diff --git a/tests/manual/model3ds/README b/tests/manual/model3ds/README
index 63630c781..4b358d272 100644
--- a/tests/manual/model3ds/README
+++ b/tests/manual/model3ds/README
@@ -9,4 +9,4 @@ The third mesh is a heirarchic mesh with no materials.
The fourth mesh is a heirarchic mesh with colours/textures.
-All meshes should be lit & shaded, and can be manually rotated etc. as per QtQuick3D norms.
+All meshes should be lit & shaded, and can be manually rotated etc. as per Qt3D norms.
diff --git a/tests/systemtests/sys_quick3d.qtt b/tests/systemtests/sys_quick3d.qtt
index 1a3358235..b23e304ff 100644
--- a/tests/systemtests/sys_quick3d.qtt
+++ b/tests/systemtests/sys_quick3d.qtt
@@ -551,7 +551,7 @@ testcase = {
*Tested Binary:* ' + testBinary + '<br>
*Requirements:* ' + testRequirements + '<br>
| *Step* | *Verification* |
- | Launch qglinfo utility (called QtQuick3D on Windows) | the application starts, showing a window with OpenGL informations |
+ | Launch qglinfo utility (called Qt3D on Windows) | the application starts, showing a window with OpenGL informations |
| Read the information | the information displayed reflects the system OpenGL ability |
| Click on menu File - Save as | the displayed information can be saved as a text file |
| Click on menu Edit - Copy | the information are copied to the clipboard |
diff --git a/devices/symbian/examples/generate_examples_pkg.pl b/devices/symbian/examples/generate_examples_pkg.pl
index 01113edb7..3997b68b4 100644
--- a/devices/symbian/examples/generate_examples_pkg.pl
+++ b/devices/symbian/examples/generate_examples_pkg.pl
@@ -49,7 +49,7 @@ sub system_example_dirs {
sub pkg_template_files
{
- print "Recording pkg files of QtQuick3D\n";
+ print "Recording pkg files of Qt3D\n";
my @out;
#get all of the pkg files we might want.
@@ -102,7 +102,7 @@ sub parse_pkg
return $lines;
}
-open(OUTPUTPKG, ">QtQuick3D_apps_template.pkg") or die "cannot open file for reading: $!";
+open(OUTPUTPKG, ">Qt3D_apps_template.pkg") or die "cannot open file for reading: $!";
# Print the pkg file heading for our collective pkg file
print OUTPUTPKG <<PKGHEADER;
@@ -122,7 +122,7 @@ print OUTPUTPKG <<PKGHEADER;
; Default dependency to Qt libraries
(0x2001E61C), 4, 7, 3, {"Qt"}
; Default dependency to QtQuick3D libraries
(0x2002AC89), 1, 0, 0, {"Qt Quick 3D"}
; Default HW/platform dependencies
@@ -122,7 +122,7 @@ print OUTPUTPKG <<PKGHEADER;
; Default dependency to Qt libraries
(0x2001E61C), 4, 7, 3, {"Qt"}
-; Default dependency to QtQuick3D libraries
+; Default dependency to Qt3D libraries
(0x2002AC89), 1, 0, 0, {"Qt Quick 3D"}
; Default HW/platform dependencies